/*

Copyright (C) 2002-2003, Jeffrey D. Argast.

The authors make NO WARRANTY or representation, either express or implied,
with respect to this software, its quality, accuracy, merchantability, or
fitness for a particular purpose.  This software is provided "AS IS", and you,
its user, assume the entire risk as to its quality and accuracy.

Permission is hereby granted to use, copy, modify, and distribute this
software or portions thereof for any purpose, without fee, subject to these
conditions:

(1) If any part of the source code is distributed, then this
statement must be included, with this copyright and no-warranty notice
unaltered.

(2) Permission for use of this software is granted only if the user accepts
full responsibility for any undesirable consequences; the authors accept
NO LIABILITY for damages of any kind.

*/

#import "PerforceActionChange.h"
#import "MessageDefs.h"
#import "AppUtils.h"


@implementation PerforceActionChangeNew

+ (void) defaultRunFor:(id)owner selector:(SEL)aSelector
{
	PerforceActionChangeNew* action = [[[PerforceActionChangeNew alloc] init] autorelease];
	
	[action runFor:owner selector:aSelector];
}

- (void) dealloc
{
	[fOwner release];

	[super dealloc];
}

- (void) runFor:(id)owner selector:(SEL)aSelector
{
    NSMutableArray* commandAndArgs = [[[NSMutableArray alloc] init] autorelease];
	
	fOwner    = [owner retain];
	fSelector = aSelector;

	[commandAndArgs addObject:@"change"];

	[commandAndArgs addObject:@"-o"];

    [self runAction:commandAndArgs stdInString:nil readToEOF:YES];
}

- (void) processOutput: (NSString*) perforceOutput
{
	// do nothing
}

@end

//
//
//

@implementation PerforceActionChangeGet

+ (void) defaultRunFor:(id)owner selector:(SEL)aSelector identifier:(NSString*)identifier
{
	PerforceActionChangeGet* action = [[[PerforceActionChangeGet alloc] init] autorelease];

	[action runFor:owner selector:aSelector identifier:identifier];
}

- (void) dealloc
{
	[fOwner release];

	[super dealloc];
}

- (void) runFor:(id)owner selector:(SEL)aSelector identifier:(NSString*)identifier
{
    NSMutableArray* commandAndArgs = [[[NSMutableArray alloc] init] autorelease];
	
	fOwner    = [owner retain];
	fSelector = aSelector;

	[commandAndArgs addObject:@"change"];

	[commandAndArgs addObject:@"-o"];

	[commandAndArgs addObject:identifier];

    [self runAction:commandAndArgs stdInString:nil readToEOF:YES];
}

- (void) processOutput: (NSString*) perforceOutput
{
	// do nothing
}


@end

//
//
//

@implementation PerforceActionChangeDelete

+ (void) defaultRunFor:(id)owner selector:(SEL)aSelector identifier:(NSString*)identifier
{
	PerforceActionChangeDelete* action = [[[PerforceActionChangeDelete alloc] init] autorelease];

	[action runFor:owner selector:aSelector identifier:identifier];
}

- (void) dealloc
{
	[fOwner release];

	[super dealloc];
}

- (void) runFor:(id)owner selector:(SEL)aSelector identifier:(NSString*)identifier
{
    NSMutableArray* commandAndArgs = [[[NSMutableArray alloc] init] autorelease];
	
	fOwner    = [owner retain];
	fSelector = aSelector;

	[commandAndArgs addObject:@"change"];

	[commandAndArgs addObject:@"-d"];

	[commandAndArgs addObject:identifier];

    [self runAction:commandAndArgs stdInString:nil readToEOF:YES];
}

- (void) notifyOwnerTaskIsComplete
{
	[super notifyOwnerTaskIsComplete];
	
	if ( [self wasSuccess] )
	{
		SendNotification (kChangeChanged);
	}
}

@end

//
//
//

@implementation PerforceActionChangeIn

+ (void) defaultRunFor:(id)owner selector:(SEL)aSelector form:(NSString*)form
{
	PerforceActionChangeIn* action = [[[PerforceActionChangeIn alloc] init] autorelease];

	[action runFor:owner selector:aSelector form:form];
}

- (void) dealloc
{
	[fOwner release];
	[fForm release];

	[super dealloc];
}

- (void) runFor:(id)owner selector:(SEL)aSelector form:(NSString*)form
{
    NSMutableArray* commandAndArgs = [[[NSMutableArray alloc] init] autorelease];
	
	fOwner    = [owner retain];
	fSelector = aSelector;
	fForm	  = [form retain];
	
	[commandAndArgs addObject:@"change"];

	[commandAndArgs addObject:@"-i"];

    [self runAction:commandAndArgs stdInString:form readToEOF:YES sendStdInToConsole:NO];
}

- (NSString*) getForm
{
	return fForm;
}

- (void) notifyOwnerTaskIsComplete
{
	[super notifyOwnerTaskIsComplete];
	
	if ( [self wasSuccess] )
	{
		SendNotification (kChangeChanged);
	}
}

@end
